Tasty Installation

# Tasty Changelog

version | date | changes
--- | --- | ---
1.1 | 2006-12-06 | Upgraded Tasty to use TurboGears 1.0b1. No changes to the API, but users will want to make sure they follow the installation instructions to get all the proper requirements installed and have their configuration and deployment working. Some specific Gotchas: start script is now start-tasty.py and accepts the name of a config file as an argument workingenv.py setup is now strongly recommended. TG's default log locations have changed